pub fn create_router(
processor: Arc<SignalProcessor>,
api_keys: Vec<ApiKeyConfig>,
) -> RouterExpand description
Build the axum router with all routes and CORS enabled.
api_keys is taken from BrainConfig.access.api_keys by the caller.
pub fn create_router(
processor: Arc<SignalProcessor>,
api_keys: Vec<ApiKeyConfig>,
) -> RouterBuild the axum router with all routes and CORS enabled.
api_keys is taken from BrainConfig.access.api_keys by the caller.